@@ -73,6 +73,8 @@ class MDocument(metaclass=MetaDocument):
                 else:
                     return self.__document__[item]
             else:
+                if isinstance(self.__class__.__dict__.get(item), property):
+                    return super().__getattribute__(item)
                 raise AttributeError(item)
         except KeyError:
             raise AttributeError(item) from None
